==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_ka.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>მიმდინარეობს ვიდეო ჩაწერა. დავხუროთ ფანჯარა?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>დაბეჭდვა</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>თქვენ არ გაქვთ საკმარისი უფლება აღნიშნულ საქაღალდეზე ქმედების განსახორციელებლად</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">არასწორი საქაღალდე</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>საბაზო</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ფაილის ლოკაცია</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>გადაღება</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>პაკეტური რეჟიმი</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>თვით ტაიმერი დაგვიანება</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>გამოსვლა</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>გამოსვლის ფორმატი</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ცალი</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ცალი</translation>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>კამერა</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>კამერა არის ხელსაწყო სურათის და ვიდეოს გადასაღებად, კომპიუტერის ინტეგრირებული კამერის ანდ დამატებითი ვებ კამერის გამოყენებით</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ფაილი არ შეინახა</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">შენახვა: </translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>სურათი: </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>ვიდეო: </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>გაფართოების პარამეტრები</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">გაფართოება: </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>სურათები: </translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>ვიდეო: </translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ხმოვანი ეფექტები</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>კამერა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ჩაწერის გაჩერება</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>გახსნა</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>დაბეჭდვა</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>დახმარება</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>იარლიყის ეკრანზე ჩვენება</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>სურათის გადაღების გაჩერება</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>კონტექსტუალური მენიუ</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">სურათის გადაღება</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">ვიდეოს ჩაწერა</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">სურათის გადაღების გაჩერება</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>ვებკამერა ვერ მოიძებნა</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>ვებკამერა გამოყენებაშია</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">ჩაწერის გაჩერება</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_ka.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>მიმდინარეობს ვიდეო ჩაწერა. დავხუროთ ფანჯარა?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>ფოტო</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ვიდეო</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>კამერების გადაკეთება</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>დაბეჭდვა</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>თქვენ არ გაქვთ საკმარისი უფლება აღნიშნულ საქაღალდეზე ქმედების განსახორციელებლად</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">არასწორი საქაღალდე</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>საქაღალდის გახსნა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>საბაზო</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ფაილის ლოკაცია</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>გადაღება</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>პაკეტური რეჟიმი</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>თვით ტაიმერი დაგვიანება</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>გამოსვლა</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>გამოსვლის ფორმატი</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ცალი</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ცალი</translation>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>კამერა</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>კამერა არის ხელსაწყო სურათის და ვიდეოს გადასაღებად, კომპიუტერის ინტეგრირებული კამერის ანდ დამატებითი ვებ კამერის გამოყენებით</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ფაილი არ შეინახა</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">შენახვა: </translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>სურათი: </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>ვიდეო: </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>გაფართოების პარამეტრები</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">გაფართოება: </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>სურათები: </translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>ვიდეო: </translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ხმოვანი ეფექტები</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>არასიმეტრიული რეჟიმი</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>ფლაში</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>ქრისტალური ხაზები</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 ხაზები</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 ხაზებს</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>მაქსიმალური გადაწყვიტილება:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>კამერა</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ჩაწერის გაჩერება</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>კოპირება</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>გახსნა</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>დაბეჭდვა</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>დახმარება</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>იარლიყის ეკრანზე ჩვენება</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>სურათის გადაღების გაჩერება</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>კონტექსტუალური მენიუ</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">სურათის გადაღება</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">ვიდეოს ჩაწერა</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">სურათის გადაღების გაჩერება</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>ნორმალური</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>სიადმი</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>სითბის</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>სიცოცხლის</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>რეტრო</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>ფილმი</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>გრიზი</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>ბაის ანდ უი</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>ფლაში</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ჩართული</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>გამორთული</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>დასაშვები ამოღება</translation>
    </message>
    <message>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>ფილტრები</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>გამოსახულება</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>ვებკამერა ვერ მოიძებნა</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>ვებკამერა გამოყენებაშია</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">ჩაწერის გაჩერება</translation>
    </message>
</context>
</TS>
